/* USER CODE BEGIN Header */
/**
  ******************************************************************************
  * @file    app_threadx.c
  * @author  MCD Application Team
  * @brief   ThreadX applicative file
  ******************************************************************************
  * @attention
  *
  * Copyright (c) 2021 STMicroelectronics.
  * All rights reserved.
  *
  * This software is licensed under terms that can be found in the LICENSE file
  * in the root directory of this software component.
  * If no LICENSE file comes with this software, it is provided AS-IS.
  *
  ******************************************************************************
  */
/* USER CODE END Header */

/* Includes ------------------------------------------------------------------*/
#include "app_threadx.h"

/* Private includes ----------------------------------------------------------*/
/* USER CODE BEGIN Includes */
#include "main.h"
#include <stdio.h>

#include "sensor.h"
#include "stm32f4xx_hal.h"
#include "ssd1306.h"
#include "screen.h"
#include <stdlib.h>
#include <string.h>
#include "ssd1306_fonts.h"
/* USER CODE END Includes */

/* Private typedef -----------------------------------------------------------*/
/* USER CODE BEGIN PTD */

/* USER CODE END PTD */

/* Private define ------------------------------------------------------------*/
/* USER CODE BEGIN PD */
#define THREAD_STACK_SIZE 1024
/* USER CODE END PD */

/* Private macro -------------------------------------------------------------*/
/* USER CODE BEGIN PM */

/* USER CODE END PM */

/* Private variables ---------------------------------------------------------*/
/* USER CODE BEGIN PV */
uint8_t LED_thread_stack[THREAD_STACK_SIZE];
TX_THREAD led_thread_ptr;

uint8_t sensors_thread_stack[THREAD_STACK_SIZE];
TX_THREAD sensors_thread_ptr;

int sensor_cycle = 0;
/* USER CODE END PV */

/* Private function prototypes -----------------------------------------------*/
/* USER CODE BEGIN PFP */
VOID ledtoggle_thread_entry(ULONG intial_input);

VOID sensors_thread_entry(ULONG intial_input);

/* USER CODE END PFP */

/**
  * @brief  Application ThreadX Initialization.
  * @param memory_ptr: memory pointer
  * @retval int
  */
UINT App_ThreadX_Init(VOID *memory_ptr)
{
  UINT ret = TX_SUCCESS;
  TX_BYTE_POOL *byte_pool = (TX_BYTE_POOL*)memory_ptr;

  /* USER CODE BEGIN App_ThreadX_Init */
  (void)byte_pool;
  tx_thread_create(&led_thread_ptr, "led_thread", ledtoggle_thread_entry, 0x1234, LED_thread_stack, THREAD_STACK_SIZE, 15,15,1,TX_AUTO_START);

  tx_thread_create(&sensors_thread_ptr, "senors_thread", sensors_thread_entry, 0x2345, sensors_thread_stack, THREAD_STACK_SIZE, 15,15,1,TX_AUTO_START);
  /* USER CODE END App_ThreadX_Init */

  return ret;
}

/**
  * @brief  MX_ThreadX_Init
  * @param  None
  * @retval None
  */
void MX_ThreadX_Init(void)
{
  /* USER CODE BEGIN  Before_Kernel_Start */

  /* USER CODE END  Before_Kernel_Start */

  tx_kernel_enter();

  /* USER CODE BEGIN  Kernel_Start_Error */

  /* USER CODE END  Kernel_Start_Error */
}

/* USER CODE BEGIN 1 */
VOID ledtoggle_thread_entry(ULONG initial_input){
	printf("LED Thread Entry Reached\n");
	printf("\n");


	printf("Starting Loop...\n");
	while(1){
		HAL_GPIO_TogglePin(PC13_LED2_GPIO_Port, PC13_LED2_Pin); /*Defined in main.h*/
		tx_thread_sleep(500);
	}
}


VOID sensors_thread_entry(ULONG intial_input){

	lps22hb_t lps22hb_data;
	hts221_data_t hts221_data;
	lsm6dsl_data_t lsm6dsl_data;
	lis2mdl_data_t lis2mdl_data;

	while(1){

		if(sensor_cycle == 0){

		    ssd1306_Fill(Black);
			ssd1306_SetCursor(2, L0);
			ssd1306_WriteString("Barometer", Font_7x10, White);

			lps22hb_data    = lps22hb_data_read();
			float temp = lps22hb_data.temperature_degC;
			char tempStr[5];
			snprintf(tempStr, 5, "%0.2f", temp);
			char tempOutput[15];
			strcpy(tempOutput, "Temp:");
			strcat(tempOutput, tempStr);
			ssd1306_SetCursor(2, L1);
			ssd1306_WriteString(tempOutput, Font_6x8, White);

			float press = lps22hb_data.pressure_hPa;
			char pressStr[5];
			snprintf(pressStr, 5, "%0.2f", press);
			char pressOutput[15];
			strcpy(pressOutput, "Presr:");
			strcat(pressOutput, pressStr);
			ssd1306_SetCursor(2, L2);
			ssd1306_WriteString(pressOutput, Font_6x8, White);

			hts221_data = hts221_data_read();
			float humidity = hts221_data.humidity_perc;
			char humidityStr[5];
			snprintf(humidityStr,5, "%0.2f", humidity);
			char humidOutput[15];
			strcpy(humidOutput, "Humid:");
			strcat(humidOutput, humidityStr);
			ssd1306_SetCursor(2, L3);
			ssd1306_WriteString(humidOutput, Font_6x8, White);

			ssd1306_UpdateScreen();

		}
		if(sensor_cycle == 1){

			ssd1306_Fill(Black);
			ssd1306_SetCursor(2, L0);
			ssd1306_WriteString("Accelerometer", Font_7x10, White);

			lsm6dsl_data = lsm6dsl_data_read();
			float xa = lsm6dsl_data.acceleration_mg[0];
			float ya = lsm6dsl_data.acceleration_mg[1];
			float za = lsm6dsl_data.acceleration_mg[2];

			char xaStr[5];
			snprintf(xaStr, 5, "%0.2f", xa);
			char xaOutput[15];
			strcpy(xaOutput, "X:");
			strcat(xaOutput, xaStr);
			ssd1306_SetCursor(2, L1);
			ssd1306_WriteString(xaOutput, Font_6x8, White);

			char yaStr[5];
			snprintf(yaStr, 5, "%0.2f", ya);
			char yaOutput[15];
			strcpy(yaOutput, "Y:");
			strcat(yaOutput, yaStr);
			ssd1306_SetCursor(2, L2);
			ssd1306_WriteString(yaOutput, Font_6x8, White);

			char zaStr[5];
			snprintf(zaStr, 5, "%0.2f", za);
			char zaOutput[15];
			strcpy(zaOutput, "Z:");
			strcat(zaOutput, zaStr);
			ssd1306_SetCursor(2, L3);
			ssd1306_WriteString(zaOutput, Font_6x8, White);

			ssd1306_UpdateScreen();

		}
		if (sensor_cycle == 2){
			ssd1306_Fill(Black);
			ssd1306_SetCursor(2, L0);
			ssd1306_WriteString("Magnetometer", Font_7x10, White);

			lis2mdl_data = lis2mdl_data_read();

			float xm = lis2mdl_data.magnetic_mG[0];
			float ym = lis2mdl_data.magnetic_mG[1];
			float zm = lis2mdl_data.magnetic_mG[2];


			char xmStr[5];
			snprintf(xmStr, 5, "%0.2f", xm);
			char xmOutput[15];
			strcpy(xmOutput, "X:");
			strcat(xmOutput, xmStr);
			ssd1306_SetCursor(2, L1);
			ssd1306_WriteString(xmOutput, Font_6x8, White);

			char ymStr[5];
			snprintf(ymStr, 5, "%0.2f", ym);
			char ymOutput[15];
			strcpy(ymOutput, "Y:");
			strcat(ymOutput, ymStr);
			ssd1306_SetCursor(2, L2);
			ssd1306_WriteString(ymOutput, Font_6x8, White);

			char zmStr[5];
			snprintf(zmStr, 5, "%0.2f", zm);
			char zmOutput[15];
			strcpy(zmOutput, "Z:");
			strcat(zmOutput, zmStr);
			ssd1306_SetCursor(2, L3);
			ssd1306_WriteString(zmOutput, Font_6x8, White);

			ssd1306_UpdateScreen();
		}



		tx_thread_sleep(100);
	}

}



/* USER CODE END 1 */
